@@ -32,7 +32,7 @@
 
 #include "kernel.h"
 #include "subscriptionlistjobs.h"
-
+#include <memory>
 #include "akregator_debug.h"
 #include <KLocalizedString>
 #include <krandom.h>
@@ -309,7 +309,7 @@ FeedList::~FeedList()
 const Feed *FeedList::findByURL(const QString &feedURL) const
 {
     if (!d->urlMap.contains(feedURL)) {
-        return 0;
+        return nullptr;
     }
     const QList<Feed *> &v = d->urlMap[feedURL];
     return !v.isEmpty() ? v.front() : 0;
@@ -318,7 +318,7 @@ const Feed *FeedList::findByURL(const QString &feedURL) const
 Feed *FeedList::findByURL(const QString &feedURL)
 {
     if (!d->urlMap.contains(feedURL)) {
-        return 0;
+        return nullptr;
     }
     const QList<Feed *> &v = d->urlMap[feedURL];
     return !v.isEmpty() ? v.front() : 0;
@@ -558,7 +558,7 @@ void FeedListManagementImpl::addFeed(const QString &url, const QString &catId)
     uint folder_id = catId.split(QLatin1Char('/'), QString::SkipEmptyParts).last().toUInt();
 
     // Get the folder
-    Folder *m_folder = 0;
+    Folder *m_folder = nullptr;
     QVector<Folder *> vector = m_feedList->folders();
     for (int i = 0; i < vector.size(); ++i) {
         if (vector.at(i)->id() == folder_id) {
