@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2016 Montel Laurent <montel@kde.org>
+  Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.
@@ -25,8 +25,8 @@ using namespace Akregator;
 
 DownloadArticleJob::DownloadArticleJob(QObject *parent)
     : QObject(parent),
-      mTemporaryFile(Q_NULLPTR),
-      mAttachmentTemporaryFile(Q_NULLPTR)
+      mTemporaryFile(nullptr),
+      mAttachmentTemporaryFile(nullptr)
 {
 
 }
