@@ -23,6 +23,7 @@
 */
 
 #include "tabwidget.h"
+#include "helper_p.h"
 
 #include <QStyle>
 #include <QApplication>
@@ -38,7 +39,6 @@
 #include <QMimeData>
 
 #include "akregator_debug.h"
-#include <QApplication>
 #include <QTabWidget>
 #include <qtabbar.h>
 #include <krun.h>
@@ -336,6 +336,7 @@ void TabWidget::slotSetTitle(Frame *frame, const QString &title)
 
 void TabWidget::slotWebPageMutedOrAudibleChanged(Akregator::Frame *frame, bool isAudioMuted, bool wasRecentlyAudible)
 {
+    Q_UNUSED(wasRecentlyAudible);
     const int idx = indexOf(frame);
     if (idx < 0) {
         return;
@@ -505,7 +506,7 @@ void TabWidget::slotCloseTab()
 
 void TabWidget::slotReloadAllTabs()
 {
-    Q_FOREACH (Frame *frame, d->frames) {
+    for (Frame *frame : qAsConst(d->frames)) {
         frame->slotReload();
     }
 }
@@ -522,4 +523,3 @@ void TabWidget::slotActivateTab()
 {
     setCurrentIndex(sender()->objectName().rightRef(2).toInt() - 1);
 }
-
